@@ -2,7 +2,7 @@ from core import Widget, ControllerWidget, WidgetInstance, WidgetsList, variable
 from fields import CompoundField, InputField, HiddenField
 from fields import RowField, FieldSet, RepeatedField, TableField
 from fields import TextField, EmailField, NumberField, IntField, DateField, TimeField
-from fields import LinkField, HTMLField, SubmitButton
+from fields import LinkField, HTMLField, SubmitButton, Checkbox, TextArea
 from forms import SimpleForm
 from select import Option, SingleSelectField, MultiSelectField
 from validators import TimeConverter, OneOf, UnicodeString
